@@ -11,7 +11,21 @@ CHANNELS = [
 ]
 NICK = 'helgabot-dev'
 
-ENABLED_PLUGINS = ['stfu', 'help', 'oneliner', 'manager', 'reminders', 'crickets', 'haskell', 'flip']
+ENABLED_PLUGINS = [
+    'stfu',
+    'help',
+    'oneliner',
+    'manager',
+    'reminders',
+    'crickets',
+    'haskell',
+    'flip',
+    'reviews',
+    'hipster',
+]
+
+REVIEWS_REVIEWBOARD_URL = 'http://reviews.ddtc.cmgdigital.com'
+REVIEWS_CHANNEL_GROUP_MAPPING = {'#bottest': 'automation'}
 
 WEBHOOKS_CREDENTIALS = []
 
@@ -29,3 +43,5 @@ JIRA_AUTH = ('sduncan', 'One19@3#2')
 JIRA_REST_API = 'https://jira.cmgdigital.com/rest/api/latest/issue/{ticket}'
 
 CRICKETS_TIMEOUT = 5
+
+HIPSTER_ECHONEST_API_KEY = 'ZSPWE9WFKBPGILRSO'
